@@ -15,13 +15,18 @@ limitations under the License.
 """
 
 from langtrace_python_sdk import langtrace
-from langtrace_python_sdk.utils.with_root_span import with_langtrace_root_span
+from langtrace_python_sdk.utils.with_root_span import (
+    with_langtrace_root_span,
+    with_additional_attributes,
+)
+
 from langtrace_python_sdk.utils.prompt_registry import get_prompt_from_registry
 from langtrace_python_sdk.utils.with_root_span import SendUserFeedback
 
 __all__ = [
     "langtrace",
     "with_langtrace_root_span",
+    "with_additional_attributes",
     "get_prompt_from_registry",
     "SendUserFeedback",
 ]
